@@ -25,7 +25,7 @@
 # details.
 #
 # You should have received a copy of the GNU General Public License along with
-# this program.  If not, see <http://www.gnu.org/licenses/>.
+# this program.  If not, see <https://www.gnu.org/licenses/>.
 
 # Add the working directory to @INC and load the test driver
 use FindBin;
@@ -148,11 +148,16 @@ $ERR_command_not_found = undef;
       $ERR_nonexe_file = "$!";
   }
 
-  $_ = `./. 2>&1`;
-  if ($? == 0) {
-      print "Executed directory!  Skipping related tests.\n";
+  if ($^O =~ /cygwin/i) {
+      # For some reason the execute here gives a different answer than make's
+      print "Skipping directory execution on $^O\n";
   } else {
-      $ERR_exe_dir = "$!";
+      $_ = `./. 2>&1`;
+      if ($? == 0) {
+          print "Executed directory!  Skipping related tests.\n";
+      } else {
+          $ERR_exe_dir = "$!";
+      }
   }
 
   chmod(0000, 'file.out');
@@ -462,7 +467,7 @@ sub print_help
 sub set_defaults
 {
   # $profile = 1;
-  $testee = "GNU make";
+  $testee = "GNU Make";
   $make_path = "make";
   $tmpfilesuffix = "mk";
   if ($port_type eq 'UNIX') {
